##R --vanilla

##Ejemplo ilustrativo del uso un gráfico radial en R (paquete plotrix) para mostrar las temperaturas a lo largo del año y durante varios años. Basado en datos de la estación climática 804070, serial 1015, ubicada en la ciudad de Maracaibo, estado Zulia, Venezuela para el periodo 1953 al 2012.
## autor JR Ferrer-Paris
##http://dx.doi.org/10.6084/m9.figshare.3376117

require(plotrix)
load("EjemploClimaMaracaibo.rda")

##etiquetas para el gráfico
pos.mes <- cumsum(c(31,28,31,30,31,30,31,31,30,31,30,31))*2*pi/365
mes <- c("Ene","Feb","Mar","Abr","May","Jun","Jul","Ago","Sep","Oct","Nov","Dic")

##colores para el gráfico
clrs <- rev(rainbow(2012-1952))

##empezamos con el año 1953
tmp <- subset(dts,year %in% 1953)
ss <- !is.na(tmp$tmean)
oldpar<-radial.plot(tmp$tmean[ss],tmp$doy[ss]*2*pi,
                    main="Temperatura en estación climática de Maracaibo",
                    line.col=clrs[1],
                    lwd=1,rad.col="lightblue",clockwise=T,rp.type="p",
                    radial.lim=c(20,40),
                    label.pos=pos.mes,
                    labels=mes)

## ahora los años siguientes
for (yy in 1954:2012) {
    tmp <- subset(dts,year %in% yy)
    ss <- !is.na(tmp$tmean)
    if (any(ss)) { # algunos años no tienen datos disponibles
        oldpar<-radial.plot(tmp$tmean[ss],tmp$doy[ss]*2*pi,
                            line.col=clrs[yy-1954], lwd=1,
                            clockwise=T,rp.type="p",radial.lim=c(20,40),add=T)
        Sys.sleep(1) ## una breve pausa para visualizar la superposición de años
    }
}
